"use strict";

var _ClevertapPlugin = require("./ClevertapPlugin");

var _analytics = require("../../../core/src/analytics");

var _mockLogger = require("../../../core/src/__tests__/__helpers__/mockLogger");

var _mockSegmentStore = require("../../../core/src/__tests__/__helpers__/mockSegmentStore");

var _clevertapReactNative = _interopRequireDefault(require("clevertap-react-native"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

jest.mock('clevertap-react-native');
describe('ClevertapPlugin ', () => {
  const store = new _mockSegmentStore.MockSegmentStore();
  const clientArgs = {
    logger: (0, _mockLogger.getMockLogger)(),
    config: {
      writeKey: '123-456',
      trackApplicationLifecycleEvents: true
    },
    store
  };
  let plugin = new _ClevertapPlugin.ClevertapPlugin();
  beforeEach(() => {
    jest.clearAllMocks();
    plugin = new _ClevertapPlugin.ClevertapPlugin();
    plugin.analytics = new _analytics.SegmentClient(clientArgs);
  });
  it('sends an identify event with correct traits', async () => {
    const payload = {
      type: 'identify',
      traits: {
        name: 'John',
        phone: '(555) 555-5555',
        foo: 'bar'
      },
      userId: 'user'
    };
    const safeTraits = {
      Name: 'John',
      Phone: '(555) 555-5555',
      foo: 'bar',
      Identity: 'user'
    };
    plugin.identify(payload);
    expect(_clevertapReactNative.default.profileSet).toHaveBeenCalledTimes(1);
    expect(_clevertapReactNative.default.profileSet).toHaveBeenCalledWith(safeTraits);
  });
  it('sends an Order Completed Event', async () => {
    const payload = {
      type: 'track',
      event: 'Order Completed',
      userId: 'user',
      properties: {
        list_id: 'hot_deals_1',
        category: 'Deals',
        products: [{
          product_id: '507f1f77bcf86cd799439011',
          sku: '45790-32',
          name: 'Monopoly: 3rd Edition',
          price: 19,
          position: 1,
          category: 'Games',
          url: 'https://www.example.com/product/path',
          image_url: 'https://www.example.com/product/path.jpg'
        }, {
          product_id: '505bd76785ebb509fc183733',
          sku: '46493-32',
          name: 'Uno Card Game',
          price: 3,
          position: 2,
          category: 'Games'
        }]
      }
    };
    const chargeDetails = {
      list_id: 'hot_deals_1',
      category: 'Deals',
      Identity: 'user'
    };
    const products = [{
      product_id: '507f1f77bcf86cd799439011',
      sku: '45790-32',
      name: 'Monopoly: 3rd Edition',
      price: 19,
      position: 1,
      category: 'Games',
      url: 'https://www.example.com/product/path',
      image_url: 'https://www.example.com/product/path.jpg'
    }, {
      product_id: '505bd76785ebb509fc183733',
      sku: '46493-32',
      name: 'Uno Card Game',
      price: 3,
      position: 2,
      category: 'Games'
    }];
    plugin.track(payload);
    expect(_clevertapReactNative.default.recordChargedEvent).toHaveBeenCalledTimes(1);
    expect(_clevertapReactNative.default.recordChargedEvent).toHaveBeenCalledWith(chargeDetails, products);
  });
  it('sends a track event', async () => {
    const payload = {
      type: 'track',
      event: 'track user',
      userId: 'user',
      properties: {
        foo: 'bar'
      }
    };
    plugin.track(payload);
    expect(_clevertapReactNative.default.recordEvent).toHaveBeenCalledTimes(1);
    expect(_clevertapReactNative.default.recordEvent).toHaveBeenCalledWith(payload.event, payload.properties);
  });
  it('sends a screen event', async () => {
    const payload = {
      type: 'screen',
      properties: {
        isFirstTime: true,
        foo: 'bar'
      },
      name: 'Home'
    };
    plugin.screen(payload);
    expect(_clevertapReactNative.default.recordEvent).toHaveBeenCalledTimes(1);
    expect(_clevertapReactNative.default.recordEvent).toHaveBeenCalledWith(payload.name, payload.properties);
  });
});
//# sourceMappingURL=ClevertapPlugin.test.js.map