function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { DestinationPlugin, PluginType, generateMapTransform } from '@segment/analytics-react-native';
import { mapTraits, transformMap } from './parameterMapping';
import CleverTap from 'clevertap-react-native';
const mappedTraits = generateMapTransform(mapTraits, transformMap);
export class ClevertapPlugin extends DestinationPlugin {
  constructor() {
    super(...arguments);

    _defineProperty(this, "type", PluginType.destination);

    _defineProperty(this, "key", 'CleverTap');
  }

  identify(event) {
    const traits = event.traits;
    const safeTraits = mappedTraits(traits);
    const userId = event.userId ?? event.anonymousId;

    if (safeTraits.DOB !== undefined && safeTraits.DOB !== null && !(safeTraits.DOB instanceof Date)) {
      if (typeof safeTraits.DOB === 'string' || typeof safeTraits.DOB === 'number') {
        const birthday = new Date(safeTraits.DOB);

        if (birthday !== undefined && birthday !== null && !isNaN(birthday.getTime())) {
          safeTraits.DOB = birthday;
        }
      } else {
        var _this$analytics, _event$traits;

        delete safeTraits.DOB;
        (_this$analytics = this.analytics) === null || _this$analytics === void 0 ? void 0 : _this$analytics.logger.warn(`Birthday found "${(_event$traits = event.traits) === null || _event$traits === void 0 ? void 0 : _event$traits.birthday}" could not be parsed as a Date. Try converting to ISO format.`);
      }
    }

    let clevertapTraits = { ...safeTraits,
      Identity: userId
    };
    CleverTap.profileSet(clevertapTraits);
    return event;
  }

  track(event) {
    if (event.event === 'Order Completed') {
      const userId = event.userId ?? event.anonymousId;
      let {
        products = [],
        ...props
      } = event.properties ?? {};
      let chargeDetails = { ...props,
        Identity: userId
      };
      let sanitizedProducts = products ?? [];
      CleverTap.recordChargedEvent(chargeDetails, sanitizedProducts);
    } else {
      CleverTap.recordEvent(event.event, event.properties);
    }

    return event;
  }

  screen(event) {
    const screenName = event.name ?? 'Screen Viewed';
    const userId = event.userId ?? event.anonymousId;
    const screenProps = { ...event.properties,
      Identity: userId
    };
    CleverTap.recordEvent(screenName, screenProps);
    return event;
  }

}
//# sourceMappingURL=ClevertapPlugin.js.map